@@ -277,6 +277,42 @@ class TestIntervalStats(unittest.TestCase):
         #print(google.protobuf.json_format.MessageToJson(msg, preserving_proto_field_name=True))
         self.assertEqual(expected_msg, msg)
 
+    def test_interval_stats_02_modules(self):
+        """Do a basic tests for all counter fields for mesgs with modules."""
+        # Use two intervals of a real captured message to test this.
+        with open('test/data/m1_1_time20_32.json') as f:
+            json1 = f.read()
+
+        with open('test/data/m1_2_time20_36.json') as f:
+            json2 = f.read()
+
+        with open('test/data/m1_3_time20_39.json') as f:
+            json3 = f.read()
+
+        with open('test/data/m1_interval_time20_35.json') as f:
+            expected_result = f.read()
+
+        msg1 = NetworkElementUpdate()
+        google.protobuf.json_format.Parse(json1, msg1)
+        msg2 = NetworkElementUpdate()
+        google.protobuf.json_format.Parse(json2, msg2)
+
+        msg3 = NetworkElementUpdate()
+        google.protobuf.json_format.Parse(json3, msg3)
+
+        expected_msg = NetworkElementUpdate()
+        google.protobuf.json_format.Parse(expected_result, expected_msg)
+
+        msg = self.mgr.handle_message(msg1)
+        self.assertIsNone(msg)
+        msg = self.mgr.handle_message(msg2)
+        self.assertIsNotNone(msg)
+        # The first one is all null's for the reset.
+        msg = self.mgr.handle_message(msg3)
+        self.assertIsNotNone(msg)
+        #print(google.protobuf.json_format.MessageToJson(msg, preserving_proto_field_name=True))
+        self.assertEqual(expected_msg, msg)
+
     def test_interval_stats_03(self):
         """Test that an incomplete messages gets timed out.
            What do we do with a partial interval that's never completed?"""
